package ai.java.back.service.impl;

import ai.java.back.entity.DailyQuestionInfo;
import ai.java.back.repository.DailyQuestionInfoRepository;
import ai.java.back.service.DailyQuestionInfoService;
import ai.java.back.service.ChatService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.io.IOException;
import java.time.LocalDate;

@Service
public class DailyQuestionInfoServiceImpl implements DailyQuestionInfoService {
    @Autowired
    private DailyQuestionInfoRepository dailyQuestionInfoRepository;

    @Autowired
    private ChatService chatService;

    @Override
    public DailyQuestionInfo getOrGenerateDiseaseByDate(LocalDate dateTime) {
        return dailyQuestionInfoRepository.findByDateTime(dateTime)
                .orElseGet(() -> {
                    String diseaseName = generateDiseaseNameByLLM(dateTime);
                    DailyQuestionInfo info = new DailyQuestionInfo();
                    info.setDateTime(dateTime);
                    info.setDiseaseName(diseaseName);
                    return dailyQuestionInfoRepository.save(info);
                });
    }

    // 只调用大模型API生成疾病名称，不做其他操作
    private String generateDiseaseNameByLLM(LocalDate date) {
        String prompt = String.format("请根据日期 %s 随机生成一个常见疾病名称，仅返回疾病名称，不要其他内容。", date.toString());
        try {
            String result = chatService.askModel(prompt);
            return result != null ? result.trim() : null;
        } catch (IOException e) {
            throw new RuntimeException("调用大模型API生成疾病名称失败", e);
        }
    }
}
